import { Component, OnInit } from '@angular/core';
import { FormGroup, FormArray, Validators, FormBuilder, ReactiveFormsModule, FormControl } from '@angular/forms';
import { TeamManagementService } from './team-management.service';
import { CommonModule } from '@angular/common';

@Component({
	selector: 'app-team',
	standalone: true,
	imports: [
		CommonModule,
		ReactiveFormsModule
	],
	templateUrl: './team-management.component.html'
})
export class TeamManagementComponent implements OnInit {
	teamForm = {} as FormGroup;
	formSubmitted = false;
	constructor(
		private formBuilder: FormBuilder,
		private teamMngService: TeamManagementService) {
	}
	ngOnInit() {
		this.createTeamForm();
	}
	
	createTeamForm() {
		this.teamForm = this.formBuilder.group({
			teamName: ['', Validators.required],
			teamManager: ['', Validators.required],
			employees: this.formBuilder.array([
				new FormControl('', [Validators.required]),
				new FormControl('', [Validators.required]),
			])
		});
	}
	get employees(): FormArray {
		return this.teamForm.get('employees') as FormArray;
	}

	onFormSubmit() {
		if (this.teamForm.valid) {
			this.teamMngService.saveTeam(this.teamForm.value);
			this.formSubmitted = true;
			this.teamForm.reset();
		} else {
			this.teamForm.get('teamName')?.markAsTouched({onlySelf: true});
			this.teamForm.get('teamManager')?.markAsTouched();
			this.teamForm.get('employees')?.markAsTouched();
			this.formSubmitted = false;
			//this.teamForm.markAllAsTouched();
		}
	}
}